<?php

namespace App\Integration;
use App\Integration\ApiRequest;

class Rappi extends ApiRequest {
    private $url = '';
    private $integrationsFactory;

    public function __construct(\App\Factory\Integrations $integrationsFactory) {
        $this->url = $_ENV['RAPPI_URL'];
        $this->integrationsFactory = $integrationsFactory;
    }
    
    public function getAuthToken(){
        return $this->integrationsFactory->getAuthToken([ 'IDINTEGRACAO' => 'RAP' ]);
    }
    
    private function getTokenField($token) {
        return ["x-authorization	: Bearer $token"];
    }
    
    private function handleTokenHeader($token) {
        return ['header' => $this->getTokenField($token)];
    }
    
    public function getMenuStatus($token, $storeId) {
        $httpCode = '';
        try {
            $url = $this->url . "/menu/approved/$storeId";
            $response = parent::get($url, array_merge(
                $this->handleTokenHeader($token),
                ['supressError' => true]
            ));
            if (isset($response['httpCode'])) {
                $httpCode = $response['httpCode'];
                throw new \Exception();
            }
            $formattedResponse = [
                'storeId' => $storeId,
                'status' => $response === 'AVAILABLE' ? 'Disponível' : 'Indisponível',
            ];
            return $formattedResponse;
        } catch (\Exception $err) {
            throw new \Exception("Não foi possível consultar o status do cardápio: $httpCode");
        }
    }
    
    public function getMenu($token, $storeId) {
        $url = $this->url . "/menu/rappi/$storeId";
        $response = parent::get($url, $this->handleTokenHeader($token));
        $decodedResponse = json_decode($response, true);
        return $decodedResponse;
    }
    
    public function postMenu($token, $data) {
        $url = $this->url . "/menu";
        $headerValue = $this->getTokenField($token);
        $headerValue[] = "Content-Type: application/json";
        $postData = json_encode($data);
        $options = [
            'header' => $headerValue,
            'data' => $postData,
            'supressError' => true,
        ];
        $result = parent::post($url, $options);
        if (isset($result['httpCode']) && $result['httpCode'] === 400) {
            $responseText = '';
            $jsonArray = json_decode($result['response'], true);
            if (isset($jsonArray['problems']) && !empty($jsonArray['problems'])) {
                foreach ($jsonArray['problems'] as $problems ) {
                    $responseText .= $problems['reason'].'<br> ';
                }
            }
            throw new \Exception($responseText);
        }
    }
}