<?php
namespace App\Report\Format;

use App\Report\IReport;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xls as XlsWriter;

class XLS implements IReport {
  public function export($data, $customOptions = []) {
    $headers = $data['visibleColumns'];
    $spreadsheet = new Spreadsheet();
    $sheet = $spreadsheet->getActiveSheet();

    $row = 1;
    $column = 'A';
    $headerMap = [];
    foreach ($headers as $header) {
      $headerKey = $header['key'];
      $headerLabel = $header['label'];
      $headerMap[$headerKey] = $headerLabel;
      $sheet->setCellValue($column . $row, $headerLabel);

      $style = array(
        'font' => array('bold' => true),
        'alignment' => array('horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER),
        'fill' => array('fillType' => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID, 'startColor' => array('rgb' => 'DDDDDD')),
        'borders' => array(
          'bottom' => array('style' => \PhpOffice\PhpSpreadsheet\Style\Border::BORDER_THIN),
        ),
      );
      $sheet->getStyle($column . $row)->applyFromArray($style);
      $sheet->getColumnDimension($column)->setAutoSize(true);

      $column++;
    }
    $row++;

    foreach ($data['order'] as $rowIndex => $items) {
      $column = 'A';
      foreach ($headers as $headerObj) {
        $headerKey = $headerObj['key'];
        $cellValue = isset($items[$headerKey]) ? $items[$headerKey] : '';
        $sheet->setCellValue($column . $row, $cellValue);

        $style = $sheet->getStyle($column . $row);
        $style->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);  

        if ($rowIndex % 2 == 1) {
            $style->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID);
            $style->getFill()->getStartColor()->setARGB('F2F2F2');
        }
          $column++;
        }
        $row++;
      }

      $writer = new XlsWriter($spreadsheet);
      $tempFolder = $this->getTemFolderPath();
      $filePath = $tempFolder . DIRECTORY_SEPARATOR . $data['title'] . '.xls';

      $writer->save($filePath);

      if (!file_exists($filePath)) {
          throw new \Exception('ERROR_WHEN_EXPORTING_REPORT_IN_XLS');
      }

      $fileContent = file_get_contents($filePath);
      $base64Content = base64_encode($fileContent);
      unlink($filePath);
      return $base64Content;
  }

  private function getTemFolderPath() {
    return sys_get_temp_dir();
  }
}
