<?php

namespace App\Service;

class Store {

    private $util;
    private $storeFactory;

    public function __construct(\App\Util\Util $util, 
                                \App\Factory\Store $storeFactory) {
        $this->util = $util;
        $this->storeFactory = $storeFactory;
    }

    public function getStores() {
        
        $stores = $this->storeFactory->getStores();

        if(!empty($stores)) {
            $stores = $this->getOnlineStores($stores);
        }

        return $stores;
    }
    
    
    public function getOnlineStores($stores) {
		$now = intval(date('Hi'));
		$day = date('w') + 1;
		
		foreach ($stores as &$s) {
			$s["open"] = false;
			
			$serviceHour = $this->storeFactory->getStoreServiceHour($s["CDFILIAL"], $s["CDLOJA"], $day);
			
			foreach ($serviceHour as $sh) {
				if (($now > intval($sh["HRINIATENDELOJA"]) && $now < intval($sh["HRFIMATENDELOJA"])) && $sh["IDATENDELOJA"] === "A") {
					$s["open"] = true;
				}
			}
		}
		
		if(isset($s)) 
		    unset($s);
		
		return $stores;
	}
	
	public function getStoreScheduledIntervals($CDFILIAL, $CDLOJA) {
	    $schedule = $this->storeFactory->getStoreScheduledIntervals($CDFILIAL, $CDLOJA);

	    foreach ($schedule as &$day){
	        $day['NMDIA'] = $this->getNameDayByNumber($day['NRDIAATENDELOJA']);

	        $hrini = $day['HRINIATENDELOJA'];
	        $hrfim = $day['HRFIMATENDELOJA'];
	        $hrini = substr($hrini, 0, 2).":".substr($hrini, 2);
	        $hrfim = substr($hrfim, 0, 2).":".substr($hrfim, 2);

	        $day['HORARIO'] = $hrini." às ".$hrfim;
	    }
	    
	    if(isset($day))
    	    unset($day);
	    
	    return $schedule;

	}
	
    private function getNameDayByNumber($dayNumber) {
        $days = [
            1 => "Domingo",
            2 => "Segunda-Feira",
            3 => "Terça-Feira",
            4 => "Quarta-Feira",
            5 => "Quinta-Feira",
            6 => "Sexta-Feira",
            7 => "Sábado"
        ];
        
        $todayNumber = date("w") + 1;
        return ($todayNumber == $dayNumber) ? "Hoje" : $days[$dayNumber];
    }

}
